"""
    Sqloquent is a package for mapping database records into objects,
    including life cycle event hooks and a relation system (i.e. ORM).
    It also includes a query builder, migration system, and other tools.
    The majority of useful features are exposed from the root level of
    the package, and the rest from sqloquent.asyncql, sqloquent.tools,
    or from invoking the tools through the CLI.
"""

__version__ = '0.5.2'

from sqloquent.classes import (
    SqlModel,
    SqlQueryBuilder,
    SqliteContext,
    DeletedModel,
    HashedModel,
    Attachment,
    Row,
    JoinedModel,
    JoinSpec,
    dynamic_sqlmodel,
)
from sqloquent.interfaces import (
    CursorProtocol,
    DBContextProtocol,
    ModelProtocol,
    QueryBuilderProtocol,
    JoinedModelProtocol,
    RowProtocol,
    RelationProtocol,
    RelatedModel,
    RelatedCollection,
)
from sqloquent.relations import (
    Relation,
    HasOne,
    HasMany,
    BelongsTo,
    BelongsToMany,
    Contains,
    Within,
    has_one,
    has_many,
    belongs_to,
    belongs_to_many,
    contains,
    within,
)
from sqloquent.migration import (
    Column,
    Table,
    Migration,
    get_index_name,
)